-- ----------------
-- CLOB-SPEICHERUNG
-- ----------------

--- Tabelle anlegen

DROP TABLE GemeindePOIs;

CREATE TABLE GemeindePOIs (
  gkz       INTEGER,                    -- Gemeindeschlssel
  poi_xml   XMLTYPE,                    -- POIs in XML
  CONSTRAINT pk_gpoi PRIMARY KEY (gkz), -- Definition Primrschlssel
  CONSTRAINT fk_gpoi_gkz FOREIGN KEY (gkz) REFERENCES Gemeinden(gkz) 
                                        -- Fremdschlssel
);

--- Daten einfgen

INSERT INTO GemeindePOIs (gkz) VALUES (3403000);

UPDATE GemeindePOIs SET poi_xml = XMLTYPE
('<?xml version="1.0"?>
  <poi-set>
    <poi>
      <name>Berliner Platz</name>
      <Point> <pos>8.21271 53.13930</pos> </Point>
    </poi>
    <poi>
      <name>Jade Hochschule</name>
      <Point> <pos>8.19974 53.14253</pos> </Point>
    </poi>
    <poi>
      <name>Bahnhof</name>
      <Point> <pos>8.22025 53.14416</pos> </Point>
    </poi>
  </poi-set>'
) WHERE gkz = 3403000;

COMMIT;

-- XML abfragen:
SELECT gkz, poi_xml FROM GemeindePOIs;

SELECT gkz, g.poi_xml.getClobVal() FROM GemeindePOIs g;
SELECT gkz, g.poi_xml.getStringVal() FROM GemeindePOIs g;

-- -------------
-- GML-ERZEUGUNG
-- -------------

-- TO_GMLGEOMETRY
SELECT name, TO_CHAR(SDO_UTIL.TO_GMLGEOMETRY(geo))
FROM GeoDbLand
WHERE id = 2 OR id = 4;

-- TO_GML311GEOMETRY
SELECT name, TO_CHAR(SDO_UTIL.TO_GML311GEOMETRY(geo))
FROM GeoDbLand
WHERE id = 2 OR id = 4;


-- -----------------
-- GML-KONSTRUKTOREN
-- -----------------

-- GML2:
UPDATE GeoDbLand SET geo = SDO_UTIL.FROM_GMLGEOMETRY(
'<gml:LineString xmlns:gml="http://www.opengis.net/gml"><gml:coordinates>4,4 5,7 8,8</gml:coordinates></gml:LineString>'
) WHERE name = 'Steg';

UPDATE GeoDbLand SET geo = SDO_UTIL.FROM_GMLGEOMETRY(
'<LineString><coordinates>4,4 5,7 8,8</coordinates></LineString>'
) WHERE name = 'Steg';

-- GML3:
UPDATE GeoDbLand SET geo = SDO_UTIL.FROM_GML311GEOMETRY(
'<LineString><posList srsDimension="2">4 4 5 7 8 8</posList></LineString>'
) WHERE name = 'Steg';

-- GML3:
UPDATE GeoDbLand SET geo = SDO_UTIL.FROM_GML311GEOMETRY(
'<Curve><segments><LineStringSegment><posList srsDimension="2">4 4 5 7 8 8' || '</posList></LineStringSegment></segments></Curve>'
) WHERE name = 'Steg';

ROLLBACK;
